scrapy_prometheus
*****************

.. image:: https://img.shields.io/pypi/status/scrapy_prometheus.svg
    :target: https://github.com/sashgorokhov/scrapy_prometheus

.. image:: https://travis-ci.org/sashgorokhov/scrapy_prometheus.svg?branch=master
    :target: https://travis-ci.org/sashgorokhov/scrapy_prometheus

.. image:: https://img.shields.io/github/license/sashgorokhov/scrapy_prometheus.svg
    :target: https://raw.githubusercontent.com/sashgorokhov/scrapy_prometheus/master/LICENSE

Exporting scrapy stats as prometheus metrics through pushgateway service.


Installation
============

Via pip:

.. code-block:: console

    pip install scrapy_prometheus